function J=jac(sigma)
%
% J=jac(sigma)
% 
% Function J=jac(sigma)computes the forward model 
% derivatives for the EM-38 problem (example 10.2)
% using the forward difference method.
%
% Input Parameters:
%   sigma - array of conductivities per layer
%
% Output Parameters:
%   J - matrix of Jacobian values
%
% Globals:
%   HDATA       vector of measured data in horizontal mode.
%   HHEIGHT     heights for vdata.
%   VDATA       vector of measured data in vertical mode.
%   VHEIGHT     heights for vdata.
%   ALPHA       regularization parameter.
%   L           smoothing matrix.
%   M           number of layers.
%   D           layer thicknesses.
%
global VHEIGHT;
global VDATA;
global HHEIGHT;
global HDATA;
global ALPHA;
global L;
global M;
global D;

%
% Figure out the size of L.
%
[nrows,ncols]=size(L);
%
% Now, loop through the model parameters, computing derivatives.
%
J=zeros(length(VDATA)+length(HDATA)+nrows,M);
I=eye(M);
h=1.0e-3;
fun0=fun(sigma);
for i=1:M
  h2=h*abs(sigma(i));
  J(:,i)=(fun(sigma+h2*I(:,i))-fun0)/h2;
end
